=========
Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <https://keepachangelog.com/en/1.0.0/>`_,
and this project adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_.

`0.0.1`_ (2023-07-21)
---------------------

Added
~~~~~

* First release on PyPI.

.. _`0.0.1`: https://gitlab.com/ugognw/ase-stubs/-/tree/v0.0.1?ref_type=tags
